@@ -1842,6 +1842,23 @@ def test__get_inputs_and_attachments_safe_unhashable_default() -> None:
     assert expected == actual
 
 
+def test_attachment_detection_with_string_annotations() -> None:
+    """Test that string annotations are handled correctly."""
+
+    # Create a function with string annotations manually
+    def foo(bar: "Annotated[bytes, ls_schemas.Attachment]"):
+        return "test"
+
+    sig = inspect.signature(foo)
+    test_attachment = ls_schemas.Attachment(mime_type="text/plain", data=b"test")
+    inputs, attachments = _get_inputs_and_attachments_safe(
+        sig, test_attachment, func=foo
+    )
+
+    assert inputs == {}
+    assert attachments == {"bar": test_attachment}
+
+
 def test_traceable_iterator_process_chunk(mock_client: Client) -> None:
     with tracing_context(enabled=True):
 
